@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.52';
+$Test::BDD::Cucumber::Executor::VERSION = '0.54';
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.52
+version 0.54
 
 =head1 DESCRIPTION
 
@@ -15,7 +15,9 @@ Definitions, and reporting on progress through the passed-in harness.
 
 =cut
 
-use Moose;
+use Moo;
+use MooX::HandlesVia;
+use Types::Standard qw( Bool ArrayRef HashRef );
 use Clone qw(clone);
 use List::Util qw/first/;
 use List::MoreUtils qw/pairwise/;
@@ -66,7 +68,7 @@ use Test::BDD::Cucumber::Util;
 use Test::BDD::Cucumber::Model::Result;
 use Test::BDD::Cucumber::Errors qw/parse_error_from_line/;
 
-has '_bail_out' => ( is => 'rw', isa => 'Bool', default => 0 );
+has '_bail_out' => ( is => 'rw', isa => Bool, default => 0 );
 
 =head1 METHODS
 
@@ -92,9 +94,9 @@ The C<pre_*> will be called in order 2, 3, 1, and C<post_*> will be called in
 
 has extensions => (
     is      => 'ro',
-    isa     => 'ArrayRef',
-    traits  => ['Array'],
+    isa     => ArrayRef,
     default => sub { [] },
+    handles_via => 'Array',
     handles => { add_extensions => 'unshift' },
 );
 
@@ -113,7 +115,7 @@ and populates C<steps> with them.
 
 =cut
 
-has 'steps' => ( is => 'rw', isa => 'HashRef', default => sub { {} } );
+has 'steps' => ( is => 'rw', isa => HashRef, default => sub { {} } );
 
 sub add_steps {
     my ( $self, @steps ) = @_;
@@ -481,6 +483,10 @@ sub dispatch {
     $tb_return->{'builder'}->failure_output( \$output );
     $tb_return->{'builder'}->todo_output( \$output );
 
+    binmode($tb_return->{'builder'}->output(), ':utf8');
+    binmode($tb_return->{'builder'}->failure_output(), ':utf8');
+    binmode($tb_return->{'builder'}->todo_output(), ':utf8');
+
     # Make a minimum pass
     $tb_return->{'builder'}
       ->ok( 1, "Starting to execute step: " . $context->text );
