@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Harness::TestBuilder;
-$Test::BDD::Cucumber::Harness::TestBuilder::VERSION = '0.52';
+$Test::BDD::Cucumber::Harness::TestBuilder::VERSION = '0.54';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::TestBuilder - Pipes step output via Test::Builder
 
 =head1 VERSION
 
-version 0.52
+version 0.54
 
 =head1 DESCRIPTION
 
@@ -23,12 +23,13 @@ Boolean - makes tests with no matcher fail
 
 use strict;
 use warnings;
-use Moose;
+use Moo;
+use Types::Standard qw( Bool InstanceOf );
 use Test::More;
 
 extends 'Test::BDD::Cucumber::Harness';
-has 'fail_skip' => ( is => 'rw', isa => 'Bool', default => 0 );
-has '_tb_instance' => ( is => 'rw', isa => 'Test::Builder' );
+has 'fail_skip' => ( is => 'rw', isa => Bool, default => 0 );
+has '_tb_instance' => ( is => 'rw', isa => InstanceOf['Test::Builder'] );
 
 my $li = ' ' x 7;
 my $ni = ' ' x 4;
