@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Model::TagSpec;
-$Test::BDD::Cucumber::Model::TagSpec::VERSION = '0.52';
+$Test::BDD::Cucumber::Model::TagSpec::VERSION = '0.54';
 =head1 NAME
 
 Test::BDD::Cucumber::Model::TagSpec - Encapsulates tag selectors
 
 =head1 VERSION
 
-version 0.52
+version 0.54
 
 =head1 DESCRIPTION
 
@@ -17,7 +17,8 @@ way.
 
 use strict;
 use warnings;
-use Moose;
+use Moo;
+use Types::Standard qw( ArrayRef );
 use Clone qw/clone/;
 
 =head1 OVERVIEW
@@ -56,7 +57,7 @@ An arrayref representing a structure like the above.
 
 =cut
 
-has 'tags' => ( is => 'rw', isa => 'ArrayRef', default => sub { [] } );
+has 'tags' => ( is => 'rw', isa => ArrayRef, default => sub { [] } );
 
 =head1 METHODS
 
